Range-v3: ranges::v3::action::unique_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Synopsis of methods | Instances and minimal complete definitions | Public Types | Public Member Functions | List of all members
ranges::v3::action::unique_fn Struct Reference

## Synopsis of methods
constexpr action< unique_fn > | unique {}

## Instances and minimal complete definitions
struct | ConceptImpl

## Public Types
template<typename Rng , typename C = equal_to, typename P = ident>
using | Concept = concepts::models< ConceptImpl, Rng, C, P >

## Public Member Functions
template<typename Rng , typename C = equal_to, typename P = ident, typename I = iterator_t<Rng>, requires = (Concept<Rng, C, P>())>
Rng | operator() (Rng &&rng, C pred=C{}, P proj=P{}) const